==> ejc-zdsmaterialb-impl-3.0.0-20251028.064012-68-sources.jar: com/ejianc/business/zdsmaterial/material/bean/MaterialBasePriceContentEntity.java <==
package com.ejianc.business.zdsmaterial.material.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 基准价格导入子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zdsmaterial_baseprice_content")
public class MaterialBasePriceContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="baseprice_id")
    private Long basepriceId; // 父id
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="material_class_code")
    private String materialClassCode; // 物资分类编码
    @TableField(value="material_class_name")
    private String materialClassName; // 物资分类名称
    @TableField(value="material_class_id")
    private Long materialClassId; // 物资分类id
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="spec")
    private String spec; // 规格
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="base_price")
    private BigDecimal basePrice; // 基准价格(单价)

    @TableField(value="base_two_price")
    private BigDecimal baseTwoPrice; // 基准价格(单价)

    @TableField(value="base_origin_price")
    private BigDecimal baseOriginPrice; // 基准原材料同价
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_code")
    private String employeeCode; // 经办人编码
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="publish_date")
    private Date publishDate; // 发布时间
    @TableField(value="brand_id")
    private Long brandId; // 品牌id
    @TableField(value="brand_name")
    private String brandName; // 品牌名称
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商id
    @TableField(value="supplier_code")
    private String supplierCode; // 供应商编码
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="area_name")
    private String areaName; // 区域名称
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value = "contract_code")
    private String contractCode;
    @TableField(value = "contract_name")
    private String contractName;
    @TableField(value = "contract_id")
    private Long contractId;
    @TableField(value = "project_id")
    private Long projectId;
    @TableField(value = "project_code")
    private String projectCode;
    @TableField(value = "project_name")
    private String projectName;
    @TableField(value = "sign_date")
    private Date signDate;
    @TableField(value = "status")
    private Integer status;

    public BigDecimal getBaseTwoPrice() {
        return baseTwoPrice;
    }

    public void setBaseTwoPrice(BigDecimal baseTwoPrice) {
        this.baseTwoPrice = baseTwoPrice;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getSignDate() {
        return signDate;
    }

    public void setSignDate(Date signDate) {
        this.signDate = signDate;
    }

    public Long getBasepriceId() {
        return basepriceId;
    }

    public void setBasepriceId(Long basepriceId) {
        this.basepriceId = basepriceId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getMaterialClassCode() {
        return materialClassCode;
    }

    public void setMaterialClassCode(String materialClassCode) {
        this.materialClassCode = materialClassCode;
    }
    public String getMaterialClassName() {
        return materialClassName;
    }

    public void setMaterialClassName(String materialClassName) {
        this.materialClassName = materialClassName;
    }
    public Long getMaterialClassId() {
        return materialClassId;
    }

    public void setMaterialClassId(Long materialClassId) {
        this.materialClassId = materialClassId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getBasePrice() {
        return basePrice;
    }

    public void setBasePrice(BigDecimal basePrice) {
        this.basePrice = basePrice;
    }
    public BigDecimal getBaseOriginPrice() {
        return baseOriginPrice;
    }

    public void setBaseOriginPrice(BigDecimal baseOriginPrice) {
        this.baseOriginPrice = baseOriginPrice;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getPublishDate() {
        return publishDate;
    }

    public void setPublishDate(Date publishDate) {
        this.publishDate = publishDate;
    }
    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-zdsmaterialb-impl-3.0.0-20251206.064400-104-sources.jar: com/ejianc/business/zdsmaterial/material/bean/MaterialBasePriceContentEntity.java <==
package com.ejianc.business.zdsmaterial.material.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 基准价格导入子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zdsmaterial_baseprice_content")
public class MaterialBasePriceContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="baseprice_id")
    private Long basepriceId; // 父id
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="material_class_code")
    private String materialClassCode; // 物资分类编码
    @TableField(value="material_class_name")
    private String materialClassName; // 物资分类名称
    @TableField(value="material_class_id")
    private Long materialClassId; // 物资分类id
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="spec")
    private String spec; // 规格
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="base_price")
    private BigDecimal basePrice; // 基准价格(单价)

    @TableField(value="base_two_price")
    private BigDecimal baseTwoPrice; // 基准价格(单价)

    @TableField(value="base_origin_price")
    private BigDecimal baseOriginPrice; // 基准原材料同价
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_code")
    private String employeeCode; // 经办人编码
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="publish_date")
    private Date publishDate; // 发布时间
    @TableField(value="brand_id")
    private Long brandId; // 品牌id
    @TableField(value="brand_name")
    private String brandName; // 品牌名称
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商id
    @TableField(value="supplier_code")
    private String supplierCode; // 供应商编码
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="area_name")
    private String areaName; // 区域名称
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value = "contract_code")
    private String contractCode;
    @TableField(value = "contract_name")
    private String contractName;
    @TableField(value = "contract_id")
    private Long contractId;
    @TableField(value = "project_id")
    private Long projectId;
    @TableField(value = "project_code")
    private String projectCode;
    @TableField(value = "project_name")
    private String projectName;
    @TableField(value = "sign_date")
    private Date signDate;
    @TableField(value = "status")
    private Integer status;
    @TableField(value = "purchase_num")
    private BigDecimal purchaseNum;//采购数量

    @TableField(value = "groove_weight")
    private BigDecimal grooveWeight; //槽重
    @TableField(value = "lid_weight")
    private BigDecimal lidWeight; //盖重

    public BigDecimal getGrooveWeight() {
        return grooveWeight;
    }

    public void setGrooveWeight(BigDecimal grooveWeight) {
        this.grooveWeight = grooveWeight;
    }

    public BigDecimal getLidWeight() {
        return lidWeight;
    }

    public void setLidWeight(BigDecimal lidWeight) {
        this.lidWeight = lidWeight;
    }

    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }

    public BigDecimal getBaseTwoPrice() {
        return baseTwoPrice;
    }

    public void setBaseTwoPrice(BigDecimal baseTwoPrice) {
        this.baseTwoPrice = baseTwoPrice;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getSignDate() {
        return signDate;
    }

    public void setSignDate(Date signDate) {
        this.signDate = signDate;
    }

    public Long getBasepriceId() {
        return basepriceId;
    }

    public void setBasepriceId(Long basepriceId) {
        this.basepriceId = basepriceId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getMaterialClassCode() {
        return materialClassCode;
    }

    public void setMaterialClassCode(String materialClassCode) {
        this.materialClassCode = materialClassCode;
    }
    public String getMaterialClassName() {
        return materialClassName;
    }

    public void setMaterialClassName(String materialClassName) {
        this.materialClassName = materialClassName;
    }
    public Long getMaterialClassId() {
        return materialClassId;
    }

    public void setMaterialClassId(Long materialClassId) {
        this.materialClassId = materialClassId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getBasePrice() {
        return basePrice;
    }

    public void setBasePrice(BigDecimal basePrice) {
        this.basePrice = basePrice;
    }
    public BigDecimal getBaseOriginPrice() {
        return baseOriginPrice;
    }

    public void setBaseOriginPrice(BigDecimal baseOriginPrice) {
        this.baseOriginPrice = baseOriginPrice;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getPublishDate() {
        return publishDate;
    }

    public void setPublishDate(Date publishDate) {
        this.publishDate = publishDate;
    }
    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
